summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2022-07-18 15:31:26 +0300
committerEli Zaretskii <eliz@gnu.org>2022-07-18 15:31:26 +0300
commit8f9993bb3f6aa52a3f3e5f1a0744e48ade6a30d6 (patch)
tree5b960d5d7bd119ef5ae4800415746ab6e1276eb4
parentf5218385c064aa959650bfe49ca32795270851eb (diff)
downloademacs-8f9993bb3f6aa52a3f3e5f1a0744e48ade6a30d6.tar.gz
; * src/buffer.c (syms_of_buffer) <mode-line-format>: Doc fix.
-rw-r--r--src/buffer.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/buffer.c b/src/buffer.c
index 321bc88ed2c..560bdf8753b 100644
--- a/src/buffer.c
+++ b/src/buffer.c
@@ -5580,7 +5580,7 @@ the mode line appears at the bottom. */);
DEFVAR_PER_BUFFER ("mode-line-format", &BVAR (current_buffer, mode_line_format),
Qnil,
- doc: /* Template for displaying mode line for current buffer.
+ doc: /* Template for displaying mode line for a window's buffer.
The value may be nil, a string, a symbol or a list.
@@ -5593,6 +5593,9 @@ For any symbol other than t or nil, the symbol's value is processed as
`risky-local-variable' property, all properties in any strings, as
well as all :eval and :propertize forms in the value, are ignored.
+When the value is processed, the window's buffer is temporarily the
+current buffer.
+
A list whose car is a string or list is processed by processing each
of the list elements recursively, as separate mode line constructs,
and concatenating the results.